            #GIT_CMT=83404ee4a816c8ee32c1b0e13985bc4b2ae6f561
# Copyright(c) 2015-2018 Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

%global package_version 5.0.1
%global container_tag 5.0

%global kolla_user      kolla
%global kolla_group     %{kolla_user}

%global docker_group    docker

%define _unpackaged_files_terminate_build 0

##### Start openstack-kolla ######
Summary:        Oracle OpenStack Deployment
Name:           openstack-kolla
Source0: openstack-kolla-ansible-5.0.1.tar.bz2
Version:        %{package_version}
Release:    89.el7
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://www.oracle.com/linux/openstack/index.html
BuildArch:      noarch

Requires:       openstack-kolla-ansible     = %{package_version}-%{release}
Requires:       openstack-kolla-preinstall  = %{package_version}-%{release}
Requires:       openstack-kolla-user        = %{package_version}-%{release}
Requires:       openstack-kolla-utils       = %{package_version}-%{release}

%description
Oracle OpenStack Meta Package


%prep
%setup -q -n openstack-kolla-ansible-%{version}


%install
# openstack-kolla
mkdir -p %{buildroot}%{_datadir}/kolla
cat >%{buildroot}%{_datadir}/kolla/LICENSE.TXT <<EOF
Oracle OpenStack is a management software package comprised of various
OpenStack components combined with independent software programs that operate
as OpenStack services. These independent programs include parts of MySQL
Community Edition, Oracle Linux and MySQL Cluster Community Edition. The
license for each OpenStack component, as well as the licenses for each
independent program, can be found in the root folder for each component and/or
program or in the specific Docker Container or RPM package.
EOF

# openstack-kolla-ansible
# Replace the openstack_release here inorder to name  '.egg-info' file with
# version
sed -i -e 's@^openstack_release:.*@openstack_release: "%{package_version}"@' \
    ansible/group_vars/all.yml

# Generate a temporary pkg-info file to make pbr happy
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: kolla-ansible
Version: %{package_version}
__EOF__

# Patches required to retain the /usr/share/kolla dir structure
mv kolla_ansible kolla
sed -i -e 's@kolla_ansible@kolla@' setup.cfg
sed -i -e 's@share/kolla-ansible@share/kolla@' setup.cfg

%{__python} setup.py build
%{__python} setup.py install --skip-build --root %{buildroot}

mkdir -m 0750 -p %{buildroot}%{_sysconfdir}/kolla
cp -r etc/kolla/* %{buildroot}%{_sysconfdir}/kolla/

chmod 0600 %{buildroot}%{_sysconfdir}/kolla/passwords.yml
mv %{buildroot}%{_sysconfdir}/kolla/globals.yml \
   %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
chmod 0660 %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__

mv -f %{buildroot}%{_datadir}/kolla/ansible/inventory \
      %{buildroot}%{_datadir}/kolla/ansible/inventory_samples

# openstack-kolla-preinstall
mkdir -p %{buildroot}%{_sysconfdir}/systemd/system/docker.service.d
cat > %{buildroot}%{_sysconfdir}/systemd/system/docker.service.d/kolla.conf << __EOF__
[Service]
MountFlags=shared
__EOF__

# openstack-kolla-user
# Create the Kolla sudo file
mkdir -p %{buildroot}%{_sysconfdir}/sudoers.d
_group=%{kolla_group}
cat >%{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user} <<__EOF__
Defaults: %{kolla_user} env_keep += "OS_AUTH_URL OS_TENANT_ID OS_TENANT_NAME OS_PROJECT_NAME"
Defaults: %{kolla_user} env_keep += "OS_USERNAME OS_PASSWORD  OS_REGION_NAME REGISTRY"
Defaults: %{kolla_user} env_keep += "OS_PROJECT_DOMAIN_ID     OS_USER_DOMAIN_ID"
Defaults: %{kolla_user} env_keep += "OS_VOLUME_API_VERSION    OS_IDENTITY_API_VERSION"

Defaults: %{kolla_user} !requiretty
Cmnd_Alias KOLLA_ADMIN_CMDS = ALL
%{kolla_user} ALL = (root) NOPASSWD: KOLLA_ADMIN_CMDS

Defaults: %${_group} !requiretty
Cmnd_Alias KOLLA_CMDS = /usr/bin/ansible, /usr/bin/ansible-playbook, /bin/ls, /bin/id
%${_group} ALL = (%{kolla_user}) NOPASSWD: KOLLA_CMDS
__EOF__

chmod 0600 %{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user}

# openstack-kolla-utils
mkdir -p %{buildroot}%{_bindir}
cp tools/docker-ostk %{buildroot}%{_bindir}/docker-ostk


%files
%defattr(0644, %{kolla_user}, %{kolla_group})
%{_datadir}/kolla/LICENSE.TXT


##### Start openstack-kolla-ansible #####
%package -n openstack-kolla-ansible

Summary:        Oracle OpenStack Ansible playbooks and supporting files
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://www.oracle.com/linux/openstack/index.html
BuildArch:      noarch

Requires:       sed
Requires:       ansible                     >= 2.3.1
Requires:       python-jinja2               >= 2.8
Requires:       python-netaddr              >= 0.7.5
Requires:       python2-debtcollector       >= 1.11.0
Requires:       python2-rfc3986             >= 0.3.1
Requires:       python-wrapt                >= 1.10.10
Requires:       python-funcsigs             >= 1.0.2
Requires:       python-monotonic            >= 0.6
Requires:       python2-oslo-utils          >= 3.22.0
Requires:       python2-oslo-config         >= 3.22.0
Requires:       python2-cryptography        >= 1.6

Requires:       openstack-kolla-user        = %{package_version}-%{release}

%description -n openstack-kolla-ansible
Ansible playbooks and support files to deploy Kolla in Docker containers.


%files -n openstack-kolla-ansible
%defattr(-, %{kolla_user}, %{kolla_group})
%config(noreplace) %{_sysconfdir}/kolla
%config(noreplace) %{_sysconfdir}/kolla/passwords.yml
%config(noreplace) %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
%dir %{_datadir}/kolla/
%dir %{_datadir}/kolla/ansible/
%dir %{_datadir}/kolla/tools/
%{_datadir}/kolla/ansible/*
%{_datadir}/kolla/tools/*
%attr(-, root, root) %{python_sitelib}/kolla/*
%{python_sitelib}/kolla*.egg-info
%{_bindir}/kolla-genpwd
%{_bindir}/kolla-mergepwd


%pre -n openstack-kolla-ansible
case "$*" in
    0)
        inst_type="install"
        ;;
    *)
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    # TODO(pbourke): this should be handled automatically?
    if  test -f %{_datadir}/kolla/ansible/group_vars/all.yml
    then
        mv %{_datadir}/kolla/ansible/group_vars/all.yml \
           %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
        chown %{kolla_user}:%{kolla_group} \
            %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
        chmod 0644 %{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    fi
    if   test -f %{_sysconfdir}/kolla/passwords.yml
    then
        cp -f %{_sysconfdir}/kolla/passwords.yml \
              %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
fi
exit 0


%post -n openstack-kolla-ansible
case "$*" in
    1)
        inst_type="install"
        ;;
    *)
        inst_type="update"
        ;;
esac

# Operations to support group / host variables
if ! test -d %{_datadir}/kolla/ansible/host_vars
then
    mkdir -m 0770 -p %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
fi
chmod 0770 %{_datadir}/kolla/ansible/group_vars

if [[ "${inst_type}" == "update" ]]
then
    # Use the default release tag if upgrading from 3.x Though we shouldn't hit
    # that since we don't support 3.x upgrades.  This is more useful going
    # forward to guide 4.x to 5.x upgrade behavior for this value
    globals_yml=%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    if grep -q '^openstack_release.*:.*"3\.[01]\.[01].*' ${globals_yml}
    then
        sed -i \
            -e 's/^openstack_release.*:/#openstack_release:/' \
            ${globals_yml}
    fi

    # Default value for TLS is now yes.  However, when upgrading from
    # a release where the default was no, we don't want to enable it
    # since the user won't have certificates installed.
    # We take no action when upgrading from a release where tls was
    # already enabled by default, or if the user has overridden the
    # value.
    all_yml_rpmsave=%{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    previous_tls_default=0
    if [[ -f $all_yml_rpmsave ]]; then
        grep -q '^kolla_enable_tls_external: "no"' $all_yml_rpmsave
        previous_tls_default=$?
    fi
    grep -q '^kolla_enable_tls_external:' $globals_yml
    tls_using_default_value=$?
    if [[ $previous_tls_default -eq 0 && $tls_using_default_value -ne 0 ]]; then
        # If a commented out value exists replace it and ensure the feature
        # is disabled.  Otherwise, add the entry to the file.
        grep -q '^#kolla_enable_tls_external:' $globals_yml
        if [[ $? -eq 0 ]]; then
            sed -i \
                -e 's/^#kolla_enable_tls_external.*/kolla_enable_tls_external: "no"/' \
                $globals_yml
        else
            echo 'kolla_enable_tls_external: "no"' >> $globals_yml
        fi
    fi

    # The default value for the keystone_token_provider is now fernet. However, when
    # upgrading from a release where the default was uuid, we don't want to change it
    # to fernet and unexpectedly break the deployment.
    # We take no action when upgrading from a release where the keystone_token_provider
    # was already fernet by default, or if the user has overridden the value.
    all_yml_rpmsave=%{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    previous_keystone_token_provider_default=0
    if [[ -f $all_yml_rpmsave ]]; then
        grep -q '^keystone_token_provider: "uuid"' $all_yml_rpmsave
        previous_keystone_token_provider_default=$?
    fi
    grep -q '^keystone_token_provider:' $globals_yml
    keystone_token_provider_value=$?
    if [[ $previous_keystone_token_provider_default -eq 0 && $keystone_token_provider_value -ne 0 ]]; then
        # If a commented out value exists replace it and ensure the feature
        # is disabled.  Otherwise, add the entry to the file.
        grep -q '^#keystone_token_provider:' $globals_yml
        if [[ $? -eq 0 ]]; then
            sed -i \
                -e 's/^#keystone_token_provider.*/keystone_token_provider: "uuid"/' \
                $globals_yml
        else
            echo 'keystone_token_provider: "uuid"' >> $globals_yml
        fi
    fi

    # Default value for barbican is now no.  However, when upgrading from
    # a release where the default was yes, we don't want to disable it.
    # We take no action when upgrading from a release where barbican was
    # already disabled by default, or if the user has overridden the
    # value.
    all_yml_rpmsave=%{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    previous_barbican_default=0
    if [[ -f $all_yml_rpmsave ]]; then
        grep -q '^enable_barbican: "yes"' $all_yml_rpmsave
        previous_barbican_default=$?
    fi
    grep -q '^enable_barbican:' $globals_yml
    barbican_using_default_value=$?
    if [[ $previous_barbican_default -eq 0 && $barbican_using_default_value -ne 0 ]]; then
        # If a commented out value exists replace it and ensure the feature
        # is disabled.  Otherwise, add the entry to the file.
        grep -q '^#enable_barbican:' $globals_yml
        if [[ $? -eq 0 ]]; then
            sed -i \
                -e 's/^#enable_barbican.*/enable_barbican: "yes"/' \
                $globals_yml
        else
            echo 'enable_barbican: "yes"' >> $globals_yml
        fi
    fi

    # Default value for murano is now no.  However, when upgrading from
    # a release where the default was yes, we don't want to disable it.
    # We take no action when upgrading from a release where murano was
    # already disabled by default, or if the user has overridden the
    # value.
    all_yml_rpmsave=%{_datadir}/kolla/ansible/group_vars/all.yml.rpmsave
    previous_murano_default=0
    if [[ -f $all_yml_rpmsave ]]; then
        grep -q '^enable_murano: "yes"' $all_yml_rpmsave
        previous_murano_default=$?
    fi
    grep -q '^enable_murano:' $globals_yml
    murano_using_default_value=$?
    if [[ $previous_murano_default -eq 0 && $murano_using_default_value -ne 0 ]]; then
        # If a commented out value exists replace it and ensure the feature
        # is disabled.  Otherwise, add the entry to the file.
        grep -q '^#enable_murano:' $globals_yml
        if [[ $? -eq 0 ]]; then
            sed -i \
                -e 's/^#enable_murano.*/enable_murano: "yes"/' \
                $globals_yml
        else
            echo 'enable_murano: "yes"' >> $globals_yml
        fi
    fi

    if test -f %{_sysconfdir}/kolla/passwords.yml.rpmsave
    then
        if test -f %{_sysconfdir}/kolla/passwords.yml.rpmnew
        then
            mv %{_sysconfdir}/kolla/passwords.yml.rpmnew %{_sysconfdir}/kolla/passwords.yml
        fi
        kolla-genpwd
        kolla-mergepwd --old %{_sysconfdir}/kolla/passwords.yml.rpmsave \
                       --new %{_sysconfdir}/kolla/passwords.yml \
                       --final %{_sysconfdir}/kolla/passwords.yml
        rm -f %{_sysconfdir}/kolla/passwords.yml.rpmsave
    fi
fi

# This forces the Oracle default values without changing what the user might
# have set on their own
# TODO(pbourke): review these in the context of 5.x
sed -i \
    -e 's/^docker_namespace:.*/docker_namespace: "openstack"/' \
    -e 's/^kolla_base_distro:.*/kolla_base_distro: "ol"/' \
    -e 's/^kolla_install_type:.*/kolla_install_type: "openstack"/' \
    -e 's/^openstack_release:.*/openstack_release: "%{container_tag}"/' \
    -e 's/^enable_cinder:.*/enable_cinder: "yes"/' \
    -e 's/^enable_multipathd:.*/enable_multipathd: "yes"/' \
    -e 's/^enable_central_logging:.*/enable_central_logging: "yes"/' \
    -e 's/^enable_aodh:.*/enable_aodh: "{{ \x27yes\x27 if enable_ceilometer | bool else \x27no\x27 }}"/' \
    -e 's/^enable_gnocchi:.*/enable_gnocchi: "{{ \x27yes\x27 if enable_ceilometer | bool else \x27no\x27 }}"/' \
    -e 's/^docker_registry:.*/docker_registry: "container-registry.oracle.com"/' \
    -e 's@^glance_file_datadir_volume:.*@glance_file_datadir_volume: "/var/lib/glance"@' \
    -e 's@^gnocchi_file_datadir_volume:.*@gnocchi_file_datadir_volume: "/var/lib/gnocchi"@' \
    %{_datadir}/kolla/ansible/group_vars/all.yml

echo 'nova_hw_disk_discard: ""' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'cinder_iscsi_helper: "lioadm"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
echo 'haproxy_defaults_balance: "source"' >> %{_datadir}/kolla/ansible/group_vars/all.yml
exit 0


##### Start openstack-kolla-preinstall #####
%package -n openstack-kolla-preinstall

Summary:        Oracle OpenStack pre-install configuration
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://www.oracle.com/linux/openstack/index.html
BuildArch:      noarch

Requires:       sudo
Requires:       docker-engine               >= 1.12.6
Requires:       btrfs-progs                 >= 4.2.2

# TODO(pbourke): get new rpm built for python-docker
Requires:       python2-docker              >= 2.4.2
Requires:       python-six                  >= 1.9.0
Requires:       openstack-kolla-user        = %{package_version}-%{release}


%description -n openstack-kolla-preinstall
Prepare a system for use by OpenStack Kolla deployments.


%files -n openstack-kolla-preinstall
%{_sysconfdir}/systemd/system/docker.service.d/kolla.conf


%post -n openstack-kolla-preinstall
case "$*" in
    1)
        inst_type="install"
        ;;
    *)
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "install" ]]; then
    systemctl daemon-reload
    systemctl enable docker
    systemctl restart docker
fi

# Prevent 'Error! pty.fork() failed: out of pty devices' errors by forcing ptmxmode=666
if grep -q '^devpts' %{_sysconfdir}/fstab
then
    sed \
     -i \
     -e '/^devpts/ s/\(.*\)\(ptmxmode=[0-9]*\)\(.*\)/\1ptmxmode=666\3/' \
     %{_sysconfdir}/fstab
else
    echo 'devpts                  /dev/pts                devpts  rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666 0 0' >>%{_sysconfdir}/fstab
fi

exit 0


##### Start openstack-kolla-user #####
%package -n openstack-kolla-user
Summary:        Oracle OpenStack User Configuration
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://www.oracle.com/linux/openstack/index.html
BuildArch:      noarch

Requires:       sudo
Requires:       shadow-utils

%description -n openstack-kolla-user
Create kolla user for use by OpenStack Kolla deployments.


%files -n openstack-kolla-user
%attr(0600, root, root) %{_sysconfdir}/sudoers.d/%{kolla_user}


%pre -n openstack-kolla-user
/usr/sbin/groupadd -f -r %{docker_group} >/dev/null 2>&1
/usr/sbin/groupadd -f -r %{kolla_group}  >/dev/null 2>&1
if ! id %{kolla_user} >/dev/null 2>&1
then
    /usr/sbin/useradd \
      -b %{_datadir} \
      -c 'Kolla User' \
      -g %{kolla_group} \
      -G %{docker_group} \
      -m \
      -k /no_skel_dir \
      -N \
      -r \
      %{kolla_user}
    [[ $? -ne 0 ]] && exit 1
    chown -f %{kolla_user}:%{kolla_group} ~%{kolla_user}
    chmod -f 0750 ~%{kolla_user}
fi
exit 0


%post -n openstack-kolla-user
# Prepare the user for SSH access
if ! test -d ~%{kolla_user}/.ssh
then
    mkdir -p -m 0700 ~%{kolla_user}/.ssh
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh
fi
if ! test -f ~%{kolla_user}/.ssh/authorized_keys
then
    touch ~%{kolla_user}/.ssh/authorized_keys
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh/authorized_keys
    chmod 0600 ~%{kolla_user}/.ssh/authorized_keys
fi
exit 0

##### Start openstack-kolla-user #####
%package -n openstack-kolla-utils

Summary:        Oracle OpenStack Utilities
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://www.oracle.com/linux/openstack/index.html
BuildArch:      noarch


%description -n openstack-kolla-utils
Utilities for use with Kolla containers.


%files -n openstack-kolla-utils
%attr(755, root, root) %{_bindir}/docker-ostk
%changelog
* Wed Aug 1 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-89.el7
- BUILDINFO: commit=83404ee4a816c8ee32c1b0e13985bc4b2ae6f561
- Flush handlers on rabbitmq[0] first during upgrade (Mick Thompson)  

* Wed Aug 01 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-88.el7
- BUILDINFO: commit=8d36707b997ce411f902ad3b467128d599d84e50
- Cinder volume HA related tweaks (Mick Thompson)

* Wed Aug 01 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-87.el7
- BUILDINFO: commit=d2010944da16d08aba7b6afb1ce5d2c3a9d3e40f
- Use iscsi initiator name from host (Vladislav Belogrudov)

* Tue Jul 31 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-86.el7
- BUILDINFO: commit=f75014f96da350171e0e5e049105bc6f9c682fd6
- Fix designate bind backend configuration (Vladislav Belogrudov)

* Tue Jul 31 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-85.el7
- BUILDINFO: commit=1d9c2ed693630859c7c0104166e396c97ab4a1a2
- Fix rabbitmq upgrade (Vladislav Belogrudov)

* Tue Jul 31 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-84.el7
- BUILDINFO: commit=9f01dd58941882d19c2dcc15b096446b76e1b5f9
- Serial start of rabbitmq nodes to seed cluster (Nikita Gerasimov)

* Tue Jul 31 2018 Mick Thompson <michael.a.thompson@oracle.com> - 5.0.1-83.el7
- BUILDINFO: commit=dba40ed2fb0fa330b38a4e530a7ca2fc59b62e44
- Remove gospel_node checks in rabbitmq upgrade task (Mick Thompson)

* Fri Jul 27 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-82.el7
- BUILDINFO: commit=ae47e2967e192b33d79866f25258a47d021d6261
- Empty commit to try and trigger build (Paul Bourke)  
- Fix rabbit hostname for clustering configuration (Vladislav Belogrudov)

* Thu Jul 26 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-81.el7
- BUILDINFO: commit=f9c4e5037f9604209413a3190424c3fdce7d9562
- Fix variable name for rabbitmq hosts (Vladislav Belogrudov)

* Thu Jul 26 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-80.el7
- BUILDINFO: commit=e056d24580614a7572d5c1f006699b8b45c59b61
- Use 'rabbit_host' in rabbitmq-env (Paul Bourke)  
- Remove old rabbit reference from rpm spec (Paul Bourke)  
- Update rabbitmq to use new conf & clustering (Paul Bourke)  
- Temporarily remove the rabbitmq clusterer plugin (Paul Bourke)

* Wed Jul 25 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-79.el7
- BUILDINFO: commit=5c94a71257a7233599fc322d9fe96fd2f38887a4
- Save targetcli configuration to a volume for container upgrades (Vladislav Belogrudov)

* Fri Jul 20 2018 Mick Thompson <michael.a.thompson@oracle.com> - 5.0.1-78.el7
- BUILDINFO: commit=99b51f17c8b05f331f79a375a23af3caa1fe3e6e
- Correct errors with license file (openstack-kolla) (Paul Bourke)

* Mon Jul 16 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-77.el7
- BUILDINFO: commit=55f094f09dcc2aea43b1788d78a510fafbfad4f5
- Extending designate named template to include "forwarders" parameter (Mark Duggan)

* Mon Jul 16 2018 Mick Thompson <michael.a.thompson@oracle.com> - 5.0.1-76.el7
- BUILDINFO: commit=ac80aa095c939171f6a58341a920201a250a87b0
- Disable barbican and murano by default (Mick Thompson)

* Fri Jul 13 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-75.el7
- BUILDINFO: commit=752d1bc8de370d32f184b93e7d7682ff172e4d6f
- Turn off NOTIFY msg from designate-worker to let mdns to do that (Murali Annamneni)

* Mon Jul 09 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-74.el7
- BUILDINFO: commit=69ab276ce2cb6fbf73da2dfca5f262b4169392cb
- Backup into NFS does not depend on Cinder volume drivers (Vladislav Belogrudov)

* Mon Jul 09 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-73.el7
- BUILDINFO: commit=5a32e91770d40a5753bc3990f0e07cd82863f224
- Ansible 2.3 does not have 'loop', use 'with_list' instead (Vladislav Belogrudov)

* Wed Jul 04 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-72.el7
- BUILDINFO: commit=40e3108f4f052a47b0a9749c07603e9f8c277845
- Add a precheck for cinder_backup_driver (Paul Bourke)

* Thu Jun 28 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-71.el7
- BUILDINFO: commit=1726e7be0c8ae6060ddece370b49f720eb903858
- update oracle-default-inventory for designate (Murali Annamneni)  
- Include localhost  in named.conf for local dns queries (Murali Annamneni)

* Thu Jun 28 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-70.el7
- BUILDINFO: commit=aa8a22f4e2ddae07f006c2298c779f279afc8842
- Fix designate interface selection (Javier Castillo Alcíbar)

* Thu Jun 28 2018 Mick Thompson <michael.a.thompson@oracle.com> - 5.0.1-69.el7
- BUILDINFO: commit=0109344170425b1961fc40be96e4e7234f40005c
- Add global container_tag definition to spec file (Mick Thompson)

* Mon Jun 25 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-68.el7
- BUILDINFO: commit=ea2bc88ae639a4621ac8e4d5b6e1d58fcf94c48a
- Check for OVM nodes before continuing with upgrade (Paul Bourke)

* Fri Jun 22 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-67.el7
- BUILDINFO: commit=778ec13f01383ebde0275b330aa904780cc54311
- New check for destroying hosts that use nfs (Mick Thompson)

* Thu Jun 21 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-66.el7
- BUILDINFO: commit=3b8c3568d94685af6fe06a527c05ad228f544fd3
- Use default version of compute API for docker-ostk (Vladislav Belogrudov)

* Thu Jun 21 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-65.el7
- BUILDINFO: commit=677094aee5695214eae8575555c35c762b4f285a
- Increase Murano agent timeout to 4h for Oracle DB RAC apps (Vladislav Belogrudov)  
- Add possibility to increase Murano agent timeout (Vladislav Belogrudov)

* Wed Jun 20 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-64.el7
- BUILDINFO: commit=cb7dc54dacf5032993b678f149ae18d7a7c13073
- config proxy settings inside glance_api container (Mark Duggan)

* Fri Jun 15 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-63.el7
- BUILDINFO: commit=e6a4687cd6ecc7caa0929704fbcf0793f148a44d
- Remove "msg" parameter from wait_for task (Nikita Gerasimov)  
- Eliminates duplicated ndb_mgmd args (Nikita Gerasimov)

* Thu Jun 14 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-62.el7
- BUILDINFO: commit=1ac80aa3b553a93f04c94a38db6c39bea748176e
- Added 'post-41' option to enable support for post MySQL v4.1client compatible checks (Murali Annamneni)

* Wed Jun 13 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-61.el7
- BUILDINFO: commit=b7b66805d5b5a6ac07e82dc7a54a91bbcad8ef4b
- Increase DB deadlock timeout to 6 sec (Vladislav Belogrudov)

* Tue Jun 12 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-60.el7
- BUILDINFO: commit=b98d5e50f4f7524b690cc1eda5b6f6da7c0e8f8b
- Include default_docker_volume_type for magnum.conf (Murali Annamneni)

* Fri Jun 08 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-59.el7
- BUILDINFO: commit=273cf69541d9701e237681ae6d5ec96b8e0be9fc
- Add nova api version to support volume multiattach (Vladislav Belogrudov)

* Wed Jun 06 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-58.el7
- BUILDINFO: commit=374fa1d0247d25f1e0a896528d86d67be19c76c8
- Fix the ceph warning after upgrade to luminous (chenxing)

* Fri May 25 2018 Nikita Gerasimov <nikita.gerasimov@oracle.com> - 5.0.1-57.el7
- BUILDINFO: commit=7904b01ecfe21521f8e9d0d971f34590a9b546c8
- Sets "haproxy_defaults_balance" to "source" (Nikita Gerasimov)

* Fri May 25 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-56.el7
- BUILDINFO: commit=9008a584fa85e1a81f40ffad3bf1f0a285991aa4
- Enable gnocchi automatically if ceilometer is enabled (Vladislav Belogrudov)

* Fri May 25 2018 Nikita Gerasimov <nikita.gerasimov@oracle.com> - 5.0.1-55.el7
- BUILDINFO: commit=50e9e9d7b604d8c1bc4d8b2fb308747f99308699
- Adds parameter to configure HAProxy defaults balance (Nikita Gerasimov)

* Fri May 25 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-54.el7
- BUILDINFO: commit=6ef61784109b0396bdfcc01d4a36d4e97c359ba5
- Update Oracle specific variables (Vladislav Belogrudov)

* Fri May 25 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-53.el7
- BUILDINFO: commit=665d3abdc75e3b09eb4b4240b64ea4ce0b89c28a
- Add precheck for Gnocchi file backend HA (Vladislav Belogrudov)

* Thu May 24 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-52.el7
- BUILDINFO: commit=88187750ce0877713107eba84a9f148b326fbbec
- Fix SSL api for multiple services (Kevin TIBI)

* Thu May 24 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-51.el7
- Fix Nova authentication in Cinder configuration file (Vladislav Belogrudov)  
- Cinder fails to run because snapshots are not compatible with secure NAS (Vladislav Belogrudov)  
- Restore config(noreplace) for __GLOBAL__ in spec file (Mick Thompson)  
- Automatically mount nfs share for Gnocchi 'file' backend (Vladislav Belogrudov)  
- Add possibility to use shared storage for file backend in Gnocchi (Vladislav Belogrudov)  
- Fix deadlock detection timeout (set back to default) (Vladislav Belogrudov)  
- Use internal interface to connect with keystone_ssh (Christian Berendt)  
- Remove obsolete mysqlcluster-data variables (Vladislav Belogrudov)

* Tue May 15 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-47.el7
- BUILDINFO: commit=42cf30fda7e8ee87c524c5548df97888256b27f2
- Make generated private key files not world readable (Mark Giles)

* Mon May 14 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-46.el7
- BUILDINFO: commit=7351c65769cdf4781ed9bcf1b73c3b87b07c4e43
- Ensure that the keystone_token_provider setting is handled correctly for upgrade (James McCarthy)

* Mon May 14 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-45.el7
- BUILDINFO: commit=9189b287a7273b2aaf599314fd849ed5a7db0b17
- Don't replace obsolete or automatic values by RPM install (Vladislav Belogrudov)  
- Fix default value logic of 'glance_backend_file' variable (Vladislav Belogrudov)

* Fri May 11 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-44.el7
- BUILDINFO: commit=31aaa5fe3481f7fe83c0281eed23e77d6242b8e1
- Automatic setup of NFS backend for Glance image store (Vladislav Belogrudov)

* Thu May 10 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-43.el7
- BUILDINFO: commit=0447bc8cd5dc8003b7433e7680da88c21100f07a
- Set balance leastconn in haproxy for ndbcluster (Paul Bourke)

* Thu May 10 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-42.el7
- BUILDINFO: commit=ec7ec56725b35374acd7e979e3f33d654a156d3e
- Merge "Fix buildrpm script"

* Wed May 09 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-41.el7
- BUILDINFO: commit=5b045e6c16d088b5dce72a160c3256416480507d
- Remove rpmsave functionality from user var files (Paul Bourke)

* Tue May 08 2018 Mick Thompson <michael.a.thompson@oracle.com> - 5.0.1-40.el7
- BUILDINFO: commit=6da48a1f47dca0fcbafb2d289033e3c60300bd78
- Add check for mounted kolla_host_mount_directory (Mick Thompson)

* Tue May 08 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-39.el7
- BUILDINFO: commit=6349e6b09e20bfb20121036bb8d4c7c613b0189b
- Fix property name conflicts for 'docker_registry' in docker-ostk (Vladislav Belogrudov)

* Mon May 07 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-38.el7
- BUILDINFO: commit=1cc6db97bfc10ef37871a4dde6a3b16acb4d63d2
- Add endpoint type specifications to murano config (Mark Giles)

* Fri May 04 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-37.el7
- BUILDINFO: commit=b8b53d4f968a5898d191771a877b1e96c60a5833
- Enable ndbcluster for heat (Paul Bourke)

* Thu May 03 2018 Gerry Buteau <gerry.buteau@oracle.com> - 5.0.1-36.el7
- BUILDINFO: commit=5e217ef9d4fa18ef2a10e67ab2580e9852827b65
- Move designate flag for 'mysql_enable_ndb' to template file (Gerry Buteau)

* Thu May 03 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-35.el7
- BUILDINFO: commit=4537e452d5a366e387d7a0f822ec64b8106b09d5
- Configure Infoblox as an IPAM driver for neutron (Gerry Buteau)

* Wed May 02 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-34.el7
- BUILDINFO: commit=c8f5b3f6648335ca628c4856130db4f6116c969f
- Reduce the default values for Ceph pgs (Paul Bourke)  
- Increase wait time for ndb (James McCarthy)  
- Add precheck for haproxy certificate file (Vladislav Belogrudov)  
- Ensure that TLS doesn't get automatically enabled by upgrade (Mark Giles)  
- Transfer OS_CACERT to docker-ostk container or use default (Vladislav Belogrudov)  
- Fix per-service upgrade error in mysqlcluster included tasks (Vladislav Belogrudov)  
- Enable TLS by default (Mark Giles)  
- Create __GLOBAL__ from __GLOBAL__.rpmsave after upgrade (Mick Thompson)  
- Fix major version upgrade logic for NDB Cluster (Vladislav Belogrudov)  
- Fix mysqlcluster upgrade logic (Vladislav Belogrudov)  
- Enable NDB support for Designate (Gerry Buteau)  
- Verify external VIP set when TLS enabled. (Mark Giles)  
- Remove unused groups for dvr mode in l3 agent template (Vladislav Belogrudov)  
- Introduce variable to allow different DVR modes (Vladislav Belogrudov)  
- Adjust inventory file for vpnaas role restructure (Murali Annamneni)  
- Restructure the vpnaas roles (chenxing)  
- Enable telemetry services in inventory file (Murali Annamneni)  
- Swift configuration misses quotas to pass DefCore (Vladislav Belogrudov)  
- Docker does not start after host reboot - not enabled (Vladislav Belogrudov)  
- Enable UTF-8 support in docker-ostk (Vladislav Belogrudov)  
- Use bind mounts for Nova volumes (Paul Bourke)  
- New murano_auth section in Murano config (ellen)  
- Add mysqlcluster condition to avoid external db precheck (Vladislav Belogrudov)  
- Add V4 ZFSSA and Murano changes to V5 (ellen)  
- Add config necessary to use Barbican with Murano (Paul Bourke)  
- Rearrange how ndb template changes are applied (James McCarthy)  
- Avoid deleting /etc/kolla/kollacli directory during host destroy (Borne Mace)  
- Enable mysql cluster in nova.conf (Vladislav Belogrudov)  
- Fix haproxy template for mysqlcluster (wrong api_interface) (Vladislav Belogrudov)  
- Fix omitted 'deployment' group (Oracle OpenStack) (Vladislav Belogrudov)

* Wed May 02 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-33.el7
- BUILDINFO: commit=aa65a0cdad3f884134ea15aad517681b6c226e82
- Revert "Rearrange how ndb template changes are applied" (James McCarthy)

* Wed May 02 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-32.el7
- BUILDINFO: commit=a0c50e87094ad4875e556d5db62a598c5190c31b
- Update swift_devices_mount_point propagation settings (James McCarthy)

* Thu Apr 26 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-31.el7
- BUILDINFO: commit=1f0407c412789eed0609e00e429a89f321c12952
- Reduce the default values for Ceph pgs (Paul Bourke)  
- Increase wait time for ndb (James McCarthy)

* Mon Apr 23 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-30.el7
- BUILDINFO: commit=9b14f05811640e673d68428e81405dd3ed55728c
- Add precheck for haproxy certificate file (Vladislav Belogrudov)

* Fri Apr 20 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-29.el7
- BUILDINFO: commit=2a76490c061976ef83beb0055ed22ea9452dbdf0
- Ensure that TLS doesn't get automatically enabled by upgrade (Mark Giles)

* Fri Apr 20 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-28.el7
- BUILDINFO: commit=8ee715760110f8031777f76042acfdc0ec514f70
- Transfer OS_CACERT to docker-ostk container or use default (Vladislav Belogrudov)

* Thu Apr 19 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-27.el7
- BUILDINFO: commit=08a662094550f4d581e0775c6c9a681406e7143b
- Fix per-service upgrade error in mysqlcluster included tasks (Vladislav Belogrudov)  
- Create __GLOBAL__ from __GLOBAL__.rpmsave after upgrade (Mick Thompson)  
- Enable TLS by default (Mark Giles)

* Tue Apr 17 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-26.el7
- BUILDINFO: commit=b4127a6584febf2f4404c33ff1eb59053a9a6b66
- Fix major version upgrade logic for NDB Cluster (Vladislav Belogrudov)

* Mon Apr 16 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-25.el7
- BUILDINFO: commit=9636defca7686899f814e95fc62e6f9d4e5cabe3
- Fix mysqlcluster upgrade logic (Vladislav Belogrudov)

* Thu Apr 12 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-24.el7
- BUILDINFO: commit=7ebbff4e2aa92a96a943e2d1779780c80af0b33b
- Enable NDB support for Designate (Gerry Buteau)

* Wed Apr 11 2018 Mark Giles <mark.giles@oracle.com> - 5.0.1-23.el7
- BUILDINFO: commit=b85c9019e8dcba6758561eaa1eb8721f8d6e9a12
- Verify external VIP set when TLS enabled. (Mark Giles)

* Mon Apr 09 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-22.el7
- BUILDINFO: commit=e42c39b0119b456ab01f2092f3eed0a304cf662c
- Fix ipc_mode comparison in the latest docker (wangwei)

* Mon Apr 09 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-21.el7
- BUILDINFO: commit=dbfbf91edc932bdcb2629da783fc4a57a9a0ff6e
- Remove unused groups for dvr mode in l3 agent template (Vladislav Belogrudov)

* Thu Apr 05 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-20.el7
- BUILDINFO: commit=6e640c7b466b3de39cb04aa7738fa14ad0a5aaef
- Introduce variable to allow different DVR modes (Vladislav Belogrudov)

* Fri Mar 30 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-19.el7
- BUILDINFO: commit=bd778f2df420c4c747d13e22e000ee3428a9a4ac
- Adjust inventory file for vpnaas role restructure (Murali Annamneni)

* Fri Mar 30 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-18.el7
- BUILDINFO: commit=9815899cd8e42a37d4f0fe3e98055fa610dd7ab4
- Restructure the vpnaas roles (chenxing)

* Wed Mar 28 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-17.el7
- BUILDINFO: commit=136624a23a7a1257d9c5b978d5f13d1f0846b8f4
- Fix wrong register variable name in ceilometer (Jeffrey Zhang)

* Wed Mar 28 2018 Murali Annamneni <murali.annamneni@oracle.com> - 5.0.1-16.el7
- BUILDINFO: commit=5980d9cbcf17d27084523e3310736571785c0369
- Enable telemetry services in inventory file (Murali Annamneni)

* Thu Mar 22 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-15.el7
- BUILDINFO: commit=7f31d8e725006a395cf5d8154181870ad1d74b38
- Docker does not start after host reboot - not enabled (Vladislav Belogrudov)  
- Swift configuration misses quotas to pass DefCore (Vladislav Belogrudov)

* Thu Mar 22 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-14.el7
- BUILDINFO: commit=30a6a1fe2467e28f84f99a7e0bf0093e78ad655c
- Enable UTF-8 support in docker-ostk (Vladislav Belogrudov)

* Fri Mar 16 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-13.el7
- BUILDINFO: commit=f3683658e9a7f7323b4c5943a3896434832552df
- Use bind mounts for Nova volumes (Paul Bourke)

* Tue Mar 13 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-12.el7
- BUILDINFO: commit=9159487823ad00e7fd289fc98d0a5165b9becbaa
- New murano_auth section in Murano config (ellen)

* Mon Mar 12 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-11.el7
- BUILDINFO: commit=90bf55fc68625775473b2ca38540c77f7f2f881f
- Add mysqlcluster condition to avoid external db precheck (Vladislav Belogrudov)  
- Add V4 ZFSSA and Murano changes to V5 (ellen)  
- Add config necessary to use Barbican with Murano (Paul Bourke)

* Wed Mar 07 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-10.el7
- BUILDINFO: commit=d7fc34afe33d648db4099b9ecbe9cd43552834b7
- Rearrange how ndb template changes are applied (James McCarthy)  
- Avoid deleting /etc/kolla/kollacli directory during host destroy (Borne Mace)  
- Enable mysql cluster in nova.conf (Vladislav Belogrudov)  
- Fix haproxy template for mysqlcluster (wrong api_interface) (Vladislav Belogrudov)  
- Fix omitted 'deployment' group (Oracle OpenStack) (Vladislav Belogrudov)  
- Use the same version for a set of kolla rpms (Vladislav Belogrudov)  
- Add autoconfigured rabbit host names into cluster configuration (Vladislav Belogrudov)  
- Added rabbit hostname autoconfiguration (Vladislav Belogrudov)  
- Add python2-docker dependency for openstack-kolla-preinstall (Vladislav Belogrudov)  
- Don't require hostnames for rabbits in advance (Vladislav Belogrudov)  
- Remerge rpm specs into one file (Paul Bourke)  
- Refactor rpm specs for 5.x (Paul Bourke)  
- Port docker-ostk for 5.x (Paul Bourke)  
- Add buildrpm for 5.x (Paul Bourke)  
- Add mysqlcluster role for 5.x (Paul Bourke)  
- Update .gitreview for stable/queens (OpenStack Release Bot)  
- Fix skydive agent openvswitch configuration (Sylvain Baubeau)  
- Fix the warning when reload the docker (caoyuan)  
- Use rpc_transport_url in blazar (zhubingbing)  
- Replace kolla title with kolla-ansible (zhubingbing)  
- Use rpc_transport_url in vitrage.conf (zhubingbing)  
- Fix fernet deploy on gate (Jeffrey Zhang)  
- Revert "Use fernet in gates" (Jeffrey Zhang)  
- Fix tacker vnffgd version (Eduardo Gonzalez)  
- Remove mariadb settings from freezer defaults/main.yml (caoyuan)  
- Support configuring grafana local admin username (Doug Szumski)  
- Fix murano authentication configuration options (Vladislav Belogrudov)  
- Use fernet in gates (Eduardo Gonzalez)  
- Add permission to notify dns server from worker (Kevin TIBI)  
- Don't check api_interface for 'deployment' group (Vladislav Belogrudov)

* Mon Mar 05 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-9.el7
- BUILDINFO: commit=cf688415f8fca0b59d799ff7f4dcb4798d71dd31
- Rearrange how ndb template changes are applied (James McCarthy)

* Fri Feb 23 2018 James McCarthy <james.m.mccarthy@oracle.com> - 5.0.1-8.el7
- BUILDINFO: commit=df31d948a7fc2a16cddacc9cd2cb84e159fcd6bf
- Avoid deleting /etc/kolla/kollacli directory during host destroy (Borne Mace)

* Wed Feb 21 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-7.el7
- BUILDINFO: commit=0dce125631c3289b13669d16d82c76221c868c14
- Enable mysql cluster in nova.conf (Vladislav Belogrudov)

* Tue Feb 20 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-6.el7
- BUILDINFO: commit=36fd13842cc5150aad89372c95b27dc0eb84b158
- Fix haproxy template for mysqlcluster (wrong api_interface) (Vladislav Belogrudov)

* Mon Feb 19 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-5.el7
- BUILDINFO: commit=bb87b4e6098637f048cc6b5c0d6df5cd38623857
- Fix murano authentication configuration options (Vladislav Belogrudov)

* Fri Feb 16 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-4.el7
- BUILDINFO: commit=568659689213dd2765d4fcae34e8433518d2b911
- Fix omitted 'deployment' group (Oracle OpenStack) (Vladislav Belogrudov)

* Wed Feb 14 2018 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 5.0.1-3.el7
- BUILDINFO: commit=b2fe34e308e43052f397a3120007055aaf227294
- Don't check api_interface for 'deployment' group (Vladislav Belogrudov)

* Wed Feb 14 2018 Gerrit Code Review <gerrit2@ca-gerrit.us.oracle.com> - 5.0.1-2.el7
- BUILDINFO: commit=8a18b2748b575c28d0a3cc16d692cd004605d8d1
- Use the same version for a set of kolla rpms (Vladislav Belogrudov)  
- Cherry pick NDBCluster commits from o3l_4.next branch (Murali Annamneni)  
- Add autoconfigured rabbit host names into cluster configuration (Vladislav Belogrudov)  
- Added rabbit hostname autoconfiguration (Vladislav Belogrudov)  
- Add python2-docker dependency for openstack-kolla-preinstall (Vladislav Belogrudov)  
- Deploy of keystone fails if api_interface names differ (Vladislav Belogrudov)  
- Don't require hostnames for rabbits in advance (Vladislav Belogrudov)

* Thu Feb 08 2018 Paul Bourke <paul.bourke@oracle.com> - 5.0.1-1
- BUILDINFO: commit=185fb431a42c0e997f363466589e3c926ddd2387
- Remerge rpm specs into one file

